@@ -66,14 +66,6 @@ var tbSyncAccountSettings = {
     }
   },
 
-
-  onInject: function (window) {
-    //called when the provider is injecting, call its onload function and pass in his AccountData Obj
-    if (tbSyncEditAccountOverlay && tbSyncEditAccountOverlay.hasOwnProperty("onload")) {
-      tbSyncEditAccountOverlay.onload(window, new TbSync.AccountData(tbSyncAccountSettings.accountID));
-    }
-  },
-
   onload: function () {
     //load observers
     Services.obs.addObserver(tbSyncAccountSettings.updateFolderListObserver, "tbsync.observer.manager.updateFolderList", false);
@@ -103,6 +95,9 @@ var tbSyncAccountSettings = {
     
     //load overlays from the provider (if any)
     TbSync.messenger.overlayManager.injectAllOverlays(window, "chrome://tbsync/content/manager/editAccount.xhtml?provider=" + tbSyncAccountSettings.provider);
+    if (window.tbSyncEditAccountOverlay && window.tbSyncEditAccountOverlay.hasOwnProperty("onload")) {
+      tbSyncEditAccountOverlay.onload(window, new TbSync.AccountData(tbSyncAccountSettings.accountID));
+    }
     tbSyncAccountSettings.loadSettings();
     
     //done, folderlist must be updated while visible
@@ -139,10 +134,10 @@ var tbSyncAccountSettings = {
 
     if (pref) {
       //is this a checkbox?
-      if (pref.tagName == "checkbox") {
+      if ((pref.tagName == "checkbox") || ((pref.tagName == "input") && (pref.type == "checkbox"))) {
         //BOOL
         if (TbSync.db.getAccountProperty(tbSyncAccountSettings.accountID, setting)) pref.setAttribute("checked", true);
-        else pref.setAttribute("checked", false);
+        else pref.removeAttribute("checked");
       } else {
         //Not BOOL
         pref.value = TbSync.db.getAccountProperty(tbSyncAccountSettings.accountID, setting);
@@ -163,10 +158,10 @@ var tbSyncAccountSettings = {
       if (pref) {
         //is this a checkbox?
         let event = "blur";
-        if (pref.tagName == "checkbox") {
+        if ((pref.tagName == "checkbox") || ((pref.tagName == "input") && (pref.type == "checkbox"))) {
           //BOOL
           if (TbSync.db.getAccountProperty(tbSyncAccountSettings.accountID, tbSyncAccountSettings.settings[i])) pref.setAttribute("checked", true);
-          else pref.setAttribute("checked", false);
+          else pref.removeAttribute("checked");
           event = "command";
         } else {
           //Not BOOL
@@ -352,7 +347,7 @@ var tbSyncAccountSettings = {
     let setting = field.id.replace("tbsync.accountsettings.pref.","");
     let value = "";
     
-    if (field.tagName == "checkbox") {
+    if ((field.tagName == "checkbox") || ((field.tagName == "input") && (field.type == "checkbox"))) {
       if (field.checked) value = true;
       else value = false;
     } else {
